'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _browserSupport = require('./browserSupport');

var _getVendorPrefixedName = require('./getVendorPrefixedName');

var _getVendorPrefixedName2 = _interopRequireDefault(_getVendorPrefixedName);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var transform = (0, _getVendorPrefixedName2.default)('transform');
var backfaceVisibility = (0, _getVendorPrefixedName2.default)('backfaceVisibility');

var translateDOMPositionXY = function () {
  if ((0, _browserSupport.hasCSSTransforms)()) {
    var ua = global.window ? global.window.navigator.userAgent : '';
    var isSafari = /Safari\//.test(ua) && !/Chrome\//.test(ua);

    // It appears that Safari messes up the composition order
    // of GPU-accelerated layers
    // (see bug https://bugs.webkit.org/show_bug.cgi?id=61824).
    // Use 2D translation instead.
    if (!isSafari && (0, _browserSupport.hasCSS3DTransforms)()) {
      return function (style, x, y) {
        style[transform] = 'translate3d(' + x + 'px,' + y + 'px,0)';
        style[backfaceVisibility] = 'hidden';
      };
    }

    return function (style, x, y) {
      style[transform] = 'translate(' + x + 'px,' + y + 'px)';
    };
  }
  return function (style, x, y) {
    style.left = x + 'px';
    style.top = y + 'px';
  };
}();

exports.default = translateDOMPositionXY;
module.exports = exports['default'];